@@ -1,10 +1,17 @@
 import os
+from dataclasses import dataclass
 from pathlib import Path
 
+from beta9 import config
 from beta9.cli.main import load_cli
-from beta9.config import SDKSettings
 
-from . import configure, login, quickstart
+from . import configure, login, logs, quickstart
+
+
+@dataclass
+class SDKSettings(config.SDKSettings):
+    realtime_host: str = os.getenv("REALTIME_HOST", "wss://rt.beam.cloud")
+
 
 settings = SDKSettings(
     name="Beam",
@@ -19,4 +26,5 @@ cli = load_cli(settings=settings)
 cli.register(configure)
 cli.register(quickstart)
 cli.register(login)
+cli.register(logs)
 cli.load_version("beam-client")
